import 'dart:typed_data';

import 'package:meta/meta.dart';
import 'package:pdf/widgets.dart';
import 'package:image/image.dart' as img;

import 'generator_card.dart';

/// Contains the assets used by the Generator. Can be re-used through multiple documents.
class GeneratorAssets {
  Map<GeneratorElement, img.Image> elementImages;
  Map<GeneratorElement, img.Image> frameImages;

  Font fontRegular;
  Font fontSemiBold;
  Font fontBold;

  TextStyle title;
  TextStyle type;
  TextStyle id;
  TextStyle cardText;
  TextStyle keyword;
  TextStyle stats;

  GeneratorAssets({
    @required ByteData fontDataRegular,
    ByteData fontDataSemiBold,
    ByteData fontDataBold,
    @required this.elementImages,
    @required this.frameImages,
  }) {
    fontRegular = Font.ttf(fontDataRegular);
    fontBold = fontDataBold == null ? fontRegular : Font.ttf(fontDataBold);
    fontSemiBold =
        fontDataSemiBold == null ? fontBold : Font.ttf(fontDataSemiBold);

    title = TextStyle(font: fontRegular, fontSize: 12);
    type = TextStyle(font: fontRegular, fontSize: 8);
    id = TextStyle(font: fontRegular, fontSize: 7);
    cardText = TextStyle(font: fontRegular, lineSpacing: 1, fontSize: 7);
    keyword = TextStyle(font: fontSemiBold, lineSpacing: 1, fontSize: 7);
    stats = TextStyle(font: fontBold, fontSize: 14);
  }
}
